      SUBROUTINE CHARFINDl(iend,imax,ncomma,icomma,cl,ctext)

C     CHARFIND FINDS SPACINGS FOR CHARACTER DELINEATED DATA

c********************************************************
c   
c   Passed Variables:
c
c    ctext:  local array (regular commafind uses cheader)
c
c    iend - size of line
c    ncomma - number of character delineated parameters found
c    imax - maximum number of character delineated parameters
c    icomma - 1. starting point of each character delineated parameter
c             2. number of characters in each parameter
c
c********************************************************

      character*1 c,cl
      character*(*) ctext

      dimension icomma(imax,2)

      ncomma=0
      icomma(1,1)=1
      do 50 nn=1,iend

c      call extractc(1,nn,c) !- cheader
       c(1:1) = ctext(nn:nn) !- passed array

       if ( c .eq. cl) then

        ncomma=ncomma+1
        icomma(ncomma,2)=nn-icomma(ncomma,1)
        icomma(ncomma+1,1)=nn+1

       endif

50    continue

      if ( iend-icomma(ncomma+1,1) .ge. 0 ) then
       ncomma=ncomma+1
       icomma(ncomma,2)=(iend-icomma(ncomma,1))+1
      endif
 
      return
      end

